..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Mpl Canvas Example
===============================================================================

An example of embedding a maplotlib plot inside an Enaml application.

.. TIP:: To see this example in action, download it from
 :download:`mpl_canvas <../../../examples/widgets/mpl_canvas.enaml>`
 and run::

   $ enaml-run mpl_canvas.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_mpl_canvas.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/widgets/mpl_canvas.enaml
    :language: enaml
